==> keytouch_2.2.2.orig.tar.gz: keytouch-2.2.2/keytouch-config/src/config_element_types.h <==
/*---------------------------------------------------------------------------------
Name               : config_element_types.h
Author             : Marvin Raaijmakers
Description        : Contains all ellement types, attribute names and attribute
                     values that appear in the (XML) configuration files.
Date of last change: 18-Aug-2005

    Copyright (C) 2005 Marvin Raaijmakers

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    You can contact me at: marvinr(at)users(dot)sf(dot)net
    (replace (at) by @ and (dot) by .)
-----------------------------------------------------------------------------------*/

/* All used attribute names in the configuration files */
#define ATTR_NAME_ACTIONTYPE		"action-type"
#define ATTR_NAME_ISDEFAULT		"isdefault"

/* All used attribute values in the configuration files */
#define ATTR_VAL_PROGRAM		"program"
#define ATTR_VAL_PLUGIN			"plugin" 

/* All used element types in the configuration files */
#define ELEM_TYPE_KEYBOARD		"keyboard"
#define ELEM_TYPE_KEYLIST		"key-list"
#define ELEM_TYPE_DEFAULTACTION		"default-action"
#define ELEM_TYPE_KEY			"key"
#define ELEM_TYPE_KEYNAME		"name"
#define ELEM_TYPE_PLUGINNAME		"plugin-name"
#define ELEM_TYPE_PLUGINFUNCTION	"plugin-function"
#define ELEM_TYPE_ACTION		"action"
#define ELEM_TYPE_PREFERENCES		"preferences"
#define ELEM_TYPE_DOCUMENTSDIR		"documents-dir"
#define ELEM_TYPE_HOMEPAGE		"home-page"
#define ELEM_TYPE_SEARCHPAGE		"search-page"
#define ELEM_TYPE_BROWSER		"browser"
#define ELEM_TYPE_EMAILPROG		"email-program"
#define ELEM_TYPE_CHATPROG		"chat-program"
#define ELEM_TYPE_CURRENTKEYBOARD	"current-keyboard"
#define ELEM_TYPE_MODEL			"model"
#define ELEM_TYPE_MANUFACTURER		"manufacturer"
#define ELEM_TYPE_KEYBOARDNAME		"keyboard-name"

==> keytouch_2.3.2.orig.tar.gz: keytouch-2.3.2/keytouch-config/src/config_element_types.h <==
/*---------------------------------------------------------------------------------
Name               : config_element_types.h
Author             : Marvin Raaijmakers
Description        : Contains all ellement types, attribute names and attribute
                     values that appear in the (XML) configuration files.
Date of last change: 15-Oct-2006
History            : 15-Oct-2006 Replaced ELEM_TYPE_DOCUMENTSDIR by
                                 ELEM_TYPE_MIXERCHANNEL

    Copyright (C) 2005-2006 Marvin Raaijmakers

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    You can contact me at: marvinr(at)users(dot)sf(dot)net
    (replace (at) by @ and (dot) by .)
-----------------------------------------------------------------------------------*/

/* All used attribute names in the configuration files */
#define ATTR_NAME_ACTIONTYPE		"action-type"
#define ATTR_NAME_ISDEFAULT		"isdefault"

/* All used attribute values in the configuration files */
#define ATTR_VAL_PROGRAM		"program"
#define ATTR_VAL_PLUGIN			"plugin" 

/* All used element types in the configuration files */
#define ELEM_TYPE_KEYBOARD		"keyboard"
#define ELEM_TYPE_KEYLIST		"key-list"
#define ELEM_TYPE_DEFAULTACTION		"default-action"
#define ELEM_TYPE_KEY			"key"
#define ELEM_TYPE_KEYNAME		"name"
#define ELEM_TYPE_PLUGINNAME		"plugin-name"
#define ELEM_TYPE_PLUGINFUNCTION	"plugin-function"
#define ELEM_TYPE_ACTION		"action"
#define ELEM_TYPE_PREFERENCES		"preferences"
#define ELEM_TYPE_MIXERCHANNEL		"mixer-channel"
#define ELEM_TYPE_HOMEPAGE		"home-page"
#define ELEM_TYPE_SEARCHPAGE		"search-page"
#define ELEM_TYPE_BROWSER		"browser"
#define ELEM_TYPE_EMAILPROG		"email-program"
#define ELEM_TYPE_CHATPROG		"chat-program"
#define ELEM_TYPE_CURRENTKEYBOARD	"current-keyboard"
#define ELEM_TYPE_MODEL			"model"
#define ELEM_TYPE_MANUFACTURER		"manufacturer"
#define ELEM_TYPE_KEYBOARDNAME		"keyboard-name"
